#[allow(dead_code)]
pub struct ContentNotification {
    pub_key: String,    
    content_id: u32
}

impl ContentNotification {

    #[allow(dead_code)]
    pub fn new(pub_key: String, content_id: u32) -> Self {
        ContentNotification{pub_key: pub_key, content_id: content_id}
    }

    pub fn get_pub_key(&self) -> &String {
        &self.pub_key
    }

    pub fn get_content_id(&self) -> &u32 {
        &self.content_id
    }
}
